@@ -86,7 +86,7 @@
 #define PLASMA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMA_NO_DEPRECATED
-#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef PLASMA_NO_DEPRECATED_WARNINGS
 #  define PLASMA_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMA_DEPRECATED_WARNINGS_SINCE PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
@@ -264,7 +264,7 @@
 #define PLASMA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMA_NO_DEPRECATED
-#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef PLASMA_NO_DEPRECATED_WARNINGS
 #  define PLASMA_DEPRECATED_WARNINGS_SINCE 0
@@ -274,7 +274,7 @@
 #  ifdef PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMA_DEPRECATED_WARNINGS_SINCE PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
